@@ -1,4 +1,6 @@
-<?php declare(strict_types=1);
+<?php
+
+declare(strict_types=1);
 
 namespace OCA\Notes\Controller;
 
@@ -164,6 +166,7 @@ class NotesApiController extends ApiController {
 			if ($favorite !== null) {
 				$note->setFavorite($favorite);
 			}
+			$this->metaService->update($this->helper->getUID(), $note);
 			return $note->getData();
 		});
 	}
